{ config, lib, pkgs, ... }:
let
    definedInPersonalDotNix = lib.mkDefault (throw "Configuration option missing from personal.nix");
in
{
    imports = [
        ./nextcloud.nix
        ./dyndns.nix
        ./adguard.nix
        ./mpd.nix
        ./burp-server.nix
        ./hedgedoc.nix
        ./transcode.nix
        ./development.nix
        ./bspwm.nix

        # ./open-pgsql.nix
    ];

    users.users = {
        waldi = {
            isNormalUser = true;
            extraGroups = [ "audio" ];
            shell = pkgs.fish;
            openssh.authorizedKeys.keys = definedInPersonalDotNix;
        };
    };
    users.extraGroups = {
        pulse-access = {
            members = [ "waldi" "fruchti" ];
        };
        music = {
            members = [ "fruchti" ];
        };
    };

    environment.systemPackages = with pkgs; [
        ntfsprogs
        texlive.combined.scheme-full
        ncmpcpp
    ];

    services.burp.client = {
        enable = true;
        password = config.services.burp.server.clients."${config.networking.hostName}".password;
    };

    # Flatpak
    services.flatpak.enable = true;
    xdg.portal.extraPortals = [ pkgs.xdg-desktop-portal-gtk ];
    xdg.portal.enable = true;

    hardware.bluetooth = {
        enable = true;
    };

    # Some programs need SUID wrappers, can be configured further or are
    # started in user sessions.
    # programs.mtr.enable = true;
    programs.gnupg.agent = {
        enable = true;
        enableSSHSupport = true;
    };

    # List services that you want to enable:

    # Enable the OpenSSH daemon.
    services.openssh = {
        enable = true;
        forwardX11 = true;
        passwordAuthentication = false;
    };

    services.avahi.enable = true;
    networking.firewall.allowedTCPPorts = [
        22
        1935  # RTMP
        4971  # BURP
    ];

    # Copy the NixOS configuration file and link it from the resulting system
    # (/run/current-system/configuration.nix). This is useful in case you
    # accidentally delete configuration.nix.
    # system.copySystemConfiguration = true;

    system.autoUpgrade.enable = true;
    system.autoUpgrade.allowReboot = true;
    system.autoUpgrade.sendEmail = true;
    # systemd.services.nixos-upgrade.onFailure = lib.mkIf config.system.autoUpgrade.enable [ "status-email@%n.service" ];

    nix.gc = {
        automatic = true;
        dates = "weekly";
        options = "--delete-older-than 30d";
    };

    services.btrfsScrub = {
        enable = true;
        paths = {
            "/" = {
                onCalendar = "*-*-* 02:00:00";
            };
            "/data" = {
                onCalendar = "Thu *-*-* 02:00:00";
            };
        };
    };

    security.acme = {
        defaults = {
            email = config.email.adminEmail;
        };
        acceptTerms = true;
    };

    services.udev.extraRules = ''
          SUBSYSTEM=="video4linux", ATTRS{idProduct}=="0002", ATTRS{idVendor}=="1d6b", SYMLINK+="hdmi_capture"
    '';
}
